#!/bin/sh

#################################################################################
#
# The purpose of this script is to enable private key authentication for
# SSH connections to ESXi. The script is deployed by a VIB in the /etc/rc.local.d/
# folder, and is started automatically by the ESXi upon the VIB installation.
# The vib containing the script is deployed upon VRA installation.
# The script is deployed with another file called 'key.pub' which contains the 
# public key of ZVM. The scripts reads the key from the this file, appends it
# to the 'authorized_keys' file at /etc/ssh/keys-root/authorized_keys if it
# doesn't exist there already, and then restarts the SSH service on the host.
#
################################################################################

BASENAME=/bin/basename
CAT=/bin/cat
CHMOD=/bin/chmod
CUT=/bin/cut
DATE=/bin/date
ECHO=/bin/echo
GREP=/bin/grep
WC=/bin/wc

UTILITY=`$BASENAME $0 | $CUT -f1 -d.`
LOGFILE=/var/log/zerto_vib_${UTILITY}.log

keys_file_changed="no"

AUTHORIZED_KEYS_FILE=/etc/ssh/keys-root/authorized_keys
KEY_PUB_FILE=/etc/rc.local.d/key.pub

date=`$DATE`
$ECHO "${date}: $UTILITY started" >> $LOGFILE

if [ ! -e $KEY_PUB_FILE ]
then
    $ECHO "Error: $KEY_PUB_FILE is not found" >> $LOGFILE
    exit 1
fi

lines=`$CAT $KEY_PUB_FILE | $WC -l`
if [ $lines -gt 1 ]
then
    $ECHO "Error: $KEY_PUB_FILE must not contain more than one line" >> $LOGFILE
    exit 1
fi

words=`$CAT $KEY_PUB_FILE | $WC -w`
if [ $words -ne 1 ]
then
    $ECHO "Error: $KEY_PUB_FILE must consist of one word" >> $LOGFILE
    exit 1
fi

KEY_PUB=`$CAT $KEY_PUB_FILE`
KEY_LINE="ssh-rsa $KEY_PUB Zerto-Zvm-key"

if [ ! -e $AUTHORIZED_KEYS_FILE ]
then
    $ECHO $KEY_LINE > $AUTHORIZED_KEYS_FILE
    keys_file_changed="yes"
else
    $GREP -xq "$KEY_LINE" $AUTHORIZED_KEYS_FILE
    RC=$?
    if [ $RC -ne 0 ]
    then
        $ECHO $KEY_LINE >> $AUTHORIZED_KEYS_FILE
        keys_file_changed="yes"
    fi
fi

$CHMOD 1600 $AUTHORIZED_KEYS_FILE

if [ $keys_file_changed = "yes" ]
then
    $ECHO "Restarting SSH..." >> $LOGFILE
    /etc/init.d/SSH restart >> $LOGFILE 2>&1
else
    $ECHO "Key already exists in $AUTHORIZED_KEYS_FILE" >> $LOGFILE
    $ECHO "SSH will not be restarted" >> $LOGFILE
fi 

date=`$DATE`
$ECHO "${date}: $UTILITY completed" >> $LOGFILE
  