#!/bin/sh

#################################################################################
#
# See the comments at the 'postinst.sh' script for background.
# This script is deployed upon VRA uninstallation. It reads the key from the key.pub 
# file deployed with it at /etc/rc.local.d and searches that key in the 'authorized_keys'.
# If the key is found, it is then removed from the authorized_keys files and the
# SSH service on the host is restarted.
#
################################################################################

BASENAME=/bin/basename
CAT=/bin/cat
CHMOD=/bin/chmod
CUT=/bin/cut
CP=/bin/cp
DATE=/bin/date
ECHO=/bin/echo
GREP=/bin/grep
RM=/bin/rm
WC=/bin/wc

UTILITY=`$BASENAME $0 | $CUT -f1 -d.`
TMP_FILE=/tmp/zerto_vib_${UTILITY}_`$DATE +%H%M%S`_$$
LOGFILE=/var/log/zerto_vib_${UTILITY}.log

AUTHORIZED_KEYS_FILE=/etc/ssh/keys-root/authorized_keys
AUTHORIZED_KEYS_FILE_BAK=${AUTHORIZED_KEYS_FILE}.prev
KEY_PUB_FILE=/etc/rc.local.d/key.pub

date=`$DATE`
$ECHO "${date}: $UTILITY started" >> $LOGFILE

if [ ! -e $AUTHORIZED_KEYS_FILE ]
then
    $ECHO "Error: $AUTHORIZED_KEYS_FILE is not found" >> $LOGFILE
    exit 1
fi

if [ ! -e $KEY_PUB_FILE ]
then
    $ECHO "Error: $KEY_PUB_FILE is not found" >> $LOGFILE
    exit 1
fi

lines=`$CAT $KEY_PUB_FILE | $WC -l`
if [ $lines -gt 1 ]
then
    $ECHO "Error: $KEY_PUB_FILE must not contain more than one line" >> $LOGFILE
    exit 1
fi

words=`$CAT $KEY_PUB_FILE | $WC -w`
if [ $words -ne 1 ]
then
    $ECHO "Error: $KEY_PUB_FILE must consist of one word" >> $LOGFILE
    exit 1
fi

KEY_PUB=`$CAT $KEY_PUB_FILE`
KEY_LINE="ssh-rsa $KEY_PUB Zerto-Zvm-key"

$GREP -xq "$KEY_LINE" $AUTHORIZED_KEYS_FILE
RC=$?
if [ $RC -eq 0 ]
then
    $CP $AUTHORIZED_KEYS_FILE $AUTHORIZED_KEYS_FILE_BAK
    $GREP -xv "$KEY_LINE" $AUTHORIZED_KEYS_FILE > $TMP_FILE
    $CP $TMP_FILE $AUTHORIZED_KEYS_FILE
    $CHMOD 1600 $AUTHORIZED_KEYS_FILE
    $RM -f $TMP_FILE 
    $RM -f $AUTHORIZED_KEYS_FILE_BAK
    
    $ECHO "Restarting SSH..." >> $LOGFILE
    /etc/init.d/SSH restart >> $LOGFILE 2>&1
else
    $ECHO "Key did not exist in $AUTHORIZED_KEYS_FILE" >> $LOGFILE
    $ECHO "SSH will not be restarted" >> $LOGFILE
fi

date=`$DATE`
$ECHO "${date}: $UTILITY completed" >> $LOGFILE
  